from typing import List, Optional

from kognic.io.model import UnixTimestampNs, BaseSerializer
from kognic.io.model.input.resources.point_cloud import PointCloud


class Frame(BaseSerializer):
    point_clouds: List[PointCloud]
    unix_timestamp: Optional[UnixTimestampNs] = None



from typing import Optional

from kognic.io.model.input.resources.resource import Resource

lidar_sensor_default = "lidar"


class PointCloud(Resource):
    filename: str
    resource_id: Optional[str] = None
    sensor_name: str = lidar_sensor_default



from typing import List

from kognic.io.model.input.abstract import BaseInputWithIMUData
from kognic.io.model.input.lidars_sequence.frame import Frame
from kognic.io.model.input.metadata.metadata import AllowedMetaData


class LidarsSequence(BaseInputWithIMUData):
    external_id: str
    frames: List[Frame]
    metadata: AllowedMetaData = dict()



from typing import List, Optional

from kognic.io.model.base_serializer import BaseSerializer
from kognic.io.model.ego.utils import UnixTimestampNs
from kognic.io.model.input.resources.image import Image
from kognic.io.model.input.resources.point_cloud import PointCloud


class Frame(BaseSerializer):
    point_clouds: List[PointCloud]
    images: List[Image]
    unix_timestamp: Optional[UnixTimestampNs] = None



from typing import List, Optional

from kognic.io.model.input.abstract import BaseInputWithIMUData
from kognic.io.model.input.lidars_and_cameras_sequence.frame import Frame
from kognic.io.model.input.metadata.metadata import AllowedMetaData
from kognic.io.model.input.sensor_specification import SensorSpecification


class LidarsAndCamerasSequence(BaseInputWithIMUData):
    external_id: str
    frames: List[Frame]
    calibration_id: str
    sensor_specification: Optional[SensorSpecification] = None
    metadata: AllowedMetaData = dict()



from typing import List, Optional

from kognic.io.model.base_serializer import BaseSerializer
from kognic.io.model.input.cameras_sequence.frame import Frame
from kognic.io.model.input.metadata.metadata import AllowedMetaData
from kognic.io.model.input.sensor_specification import SensorSpecification


class CamerasSequence(BaseSerializer):
    external_id: str
    frames: List[Frame]
    sensor_specification: Optional[SensorSpecification] = None
    metadata: AllowedMetaData = dict()



from typing import Optional

from kognic.io.model.base_serializer import BaseSerializer
from kognic.io.model.input.resources.resource import Resource

camera_sensor_default = "CAM"


class ImageMetadata(BaseSerializer):
    shutter_time_start_ns: int
    shutter_time_end_ns: int


class Image(Resource):
    filename: str
    resource_id: Optional[str] = None
    sensor_name: str = camera_sensor_default
    metadata: Optional[ImageMetadata] = None



from abc import ABC
from pathlib import Path
from typing import Optional

from pydantic import validator

from kognic.io.model.base_serializer import BaseSerializer


class Resource(ABC, BaseSerializer):
    filename: str
    resource_id: Optional[str]
    sensor_name: str

    @validator('resource_id', always=True)
    def validate_date(cls, value, values):
        if value is None:
            return str(Path(values["filename"]).expanduser())
        return value



from kognic.io.model.input.abstract import BaseInputWithIMUData
from kognic.io.model.input.lidars.frame import Frame
from kognic.io.model.input.metadata.metadata import AllowedMetaData


class Lidars(BaseInputWithIMUData):
    external_id: str
    frame: Frame
    metadata: AllowedMetaData = dict()



from typing import List, Mapping, Union

from kognic.io.model.input.abstract.sequence_frame import SequenceFrame
from kognic.io.model.input.resources import Image, VideoFrame


class Frame(SequenceFrame):
    images: List[Image] = []
    video_frames: List[VideoFrame] = []
    metadata: Mapping[str, Union[int, float, str, bool]] = {}
